Config class

Constructors

Config(eInsertType insertType, int nthMatch, String filePath, String text, String regex)

Properties

filePath String
final
hashCode int
The hash code for this object.
no setterinherited
insertType eInsertType
final
nthMatch int
final
regex String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited