findAndReplace library

Functions

findAndReplace(Config config, String input) String
Find the nth match of the regex in the input string and if eInsertType is replace then replaces it with the text if before or after then we insert the text