menu
atreeon_find_replace package
documentation
findAndReplace.dart
findAndReplace.dart
dark_mode
light_mode
findAndReplace
library
Functions
findAndReplace
(
Config
config
,
String
input
)
→
String
Find the nth match of the regex in the input string and if
eInsertType
is replace then replaces it with the text if before or after then we insert the text
atreeon_find_replace package
documentation
findAndReplace.dart
atreeon_find_replace
package
Libraries
Config
eInsertType
findAndReplace
getConfig
findAndReplace library